---
slug: "ma3-tip-clear-through-black"
title: "MA3 Tip: Clear Through Black"
date: "2025-02-24"
modified: "2025-02-24"
description: "A little GrandMA3 Macro to clear fixtures in the programmer in a more subtle way."
---
When I'm busking on GrandMA3, especially for slower, more looks-based shows, I keep making a specific kind of mistake. With Program Time turned on, clearing a fixture will fade all of it's parameters. So hitting good old clear clear clear means fixtures I've turned on will fade out, while also changing colors, gobos, zoom, position and so on. That feels quite sloppy and distracting to me. Especially since the whole point of using the programmer for busking, to me, is being able to make small changes subtly.

I've found myself dimming the fixture to 0, `Off`ing all the other parameters, and then clearing the fixture so you only see it fade out (and potentially back in if it was already on) without seeing a whole bunch of other stuff change. That's quite a lot of manual work, so I started wondering if I could write a little macro that does this for me.

That macro ended up looking like this:

| Command                           | Wait   | Note                                 |
| --------------------------------- | ------ | ------------------------------------ |
| At 0 Fade "1"                     | 1      | Dim fixtures                         |
| Off Selection If ATtribute 2 Thru | 1      | Clear attributes except dimmer       |
| Attribute At Release Fade 1       | 1      | Set fixtures to original intensity   |
| Off Selection                     | Follow | Clear release values out of fixtures |

If you want to use a different fade time, you'll want to not only change the `Fade` time in the first line, but also the wait times of the first and third lines. These wait times are there to make sure things only start clearing once the fixture is off, and to make sure the fixture fades back in before clearing the programmer entirely. The wait time of the second line makes sure that parameters that can't physically change instantly have some time to clear before fading the fixture back to it's playback intensity.

In the above version of the macro, it only clears fixtures that are currently selected, which is what I've end up usually wanting. If you want it to clear the whole programmer, you could add a macro line all the way at the top containing `Clear; IfProgrammer`. This first deselects what you've currently got selected, so that anything you have selected that doesn't contain any programmer values doesn't dip to black for no reason. Then it selects every fixture that currently has programmer values.

The last two steps might seem a little weird. why not just `Off Selection` right away? This is because Off doesn't (currently, as of 2.2.1.1) take any timing besides prog time into account. I prefer this macro working without prog time enabled (since prog time working the way it works being what drove me to figure out this little macro in the first place).

I hope it helps you make your busking just a little bit smoother, like it's been doing for me.